@@ -288,6 +288,14 @@ class JobDefinitionWrapper(PlainBoxObjectWrapper):
         # full id instead of the old name (name may be very well gone)
         return self.native.id
 
+    @dbus.service.property(dbus_interface=JOB_IFACE, signature="s")
+    def summary(self):
+        return self.native.summary
+
+    @dbus.service.property(dbus_interface=JOB_IFACE, signature="s")
+    def tr_summary(self):
+        return self.native.tr_summary()
+
     @dbus.service.property(dbus_interface=JOB_IFACE, signature="s")
     def id(self):
         return self.native.id
@@ -300,6 +308,10 @@ class JobDefinitionWrapper(PlainBoxObjectWrapper):
     def description(self):
         return self.native.description or ""
 
+    @dbus.service.property(dbus_interface=JOB_IFACE, signature="s")
+    def tr_description(self):
+        return self.native.tr_description() or ""
+
     @dbus.service.property(dbus_interface=JOB_IFACE, signature="s")
     def checksum(self):
         # This is a bit expensive to compute so let's keep it cached
@@ -1195,7 +1207,7 @@ class ServiceWrapper(PlainBoxObjectWrapper):
                             option_list: 'as', output_file: 's'):
         return self.native.export_session_to_file(
             session, output_format, option_list, output_file)
-    
+
     @dbus.service.method(
         dbus_interface=SERVICE_IFACE, in_signature='', out_signature='as')
     def GetAllTransports(self):
@@ -1205,9 +1217,11 @@ class ServiceWrapper(PlainBoxObjectWrapper):
         return self.native.get_all_transports()
 
     @dbus.service.method(
-        dbus_interface=SERVICE_IFACE, in_signature='ssss', out_signature='s')
-    def SendDataViaTransport(self, transport, where, options, data):
-        return self.native.send_data_via_transport(transport, where,
+        dbus_interface=SERVICE_IFACE, in_signature='ossss', out_signature='s')
+    @PlainBoxObjectWrapper.translate
+    def SendDataViaTransport(self, session: 'o', transport: 's', where: 's', 
+                             options: 's', data: 's'):
+        return self.native.send_data_via_transport(session, transport, where,
                                                    options, data)
 
     @dbus.service.method(
